You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@jackrabbit.apache.org by "Jukka Zitting (JIRA)" <ji...@apache.org> on 2008/08/04 16:10:44 UTC

[jira] Commented: (JCR-1705) Reduce memory usage of transient nodes

    [ https://issues.apache.org/jira/browse/JCR-1705?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=12619522#action_12619522 ] 

Jukka Zitting commented on JCR-1705:
------------------------------------

+1 I like the way you got rid of many of the sharedChildNodeEntries conditionals!

On the other hand, I don't like that we add another special case to the already complex NodeState handling. But I guess cleaning up the NodeState class is a topic for another issue.

> Reduce memory usage of transient nodes
> --------------------------------------
>
>                 Key: JCR-1705
>                 URL: https://issues.apache.org/jira/browse/JCR-1705
>             Project: Jackrabbit
>          Issue Type: Improvement
>          Components: jackrabbit-core
>            Reporter: Marcel Reutegger
>            Priority: Minor
>         Attachments: JCR-1705.patch
>
>
> When adding lots of transient nodes, most of them don't have child nodes because they are leafs. The attached patch initializes NodeState.childNodeEntries with an unmodifiable empty ChildNodeEntries instance and turns it into a modifiable one only when needed.
> Running a test with 100k nodes (10 children per node) the memory consumption for child node entries drops from 42MB to 12MB with this patch.

-- 
This message is automatically generated by JIRA.
-
You can reply to this email to add a comment to the issue online.